==> zio-aws-ec2_2.12-5.19.7.2-sources.jar: zio/aws/ec2/model/DescribeVpcEndpointServiceConfigurationsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, VpcEndpointServiceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeVpcEndpointServiceConfigurationsRequest(
    serviceIds: Optional[Iterable[VpcEndpointServiceId]] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[Integer] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest = {
    import DescribeVpcEndpointServiceConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
      .builder()
      .optionallyWith(
        serviceIds.map(value =>
          value.map { item =>
            VpcEndpointServiceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.serviceIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxResults.map(value => value: java.lang.Integer))(
        _.maxResults
      )
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
      .wrap(buildAwsValue())
}
object DescribeVpcEndpointServiceConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest =
      zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest(
        serviceIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def serviceIds: Optional[List[VpcEndpointServiceId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[Integer]
    def nextToken: Optional[String]
    def getServiceIds: ZIO[Any, AwsError, List[VpcEndpointServiceId]] =
      AwsError.unwrapOptionField("serviceIds", serviceIds)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ) extends zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly {
    override val serviceIds: Optional[List[VpcEndpointServiceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serviceIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.VpcEndpointServiceId(item)
          }.toList
        )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => value: Integer)
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ): zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/DescribeVpcEndpointServiceConfigurationsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, VpcEndpointServiceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeVpcEndpointServiceConfigurationsRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    serviceIds: Optional[Iterable[VpcEndpointServiceId]] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[Integer] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest = {
    import DescribeVpcEndpointServiceConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        serviceIds.map(value =>
          value.map { item =>
            VpcEndpointServiceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.serviceIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxResults.map(value => value: java.lang.Integer))(
        _.maxResults
      )
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
      .wrap(buildAwsValue())
}
object DescribeVpcEndpointServiceConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest =
      zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest(
        dryRun.map(value => value),
        serviceIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def serviceIds: Optional[List[VpcEndpointServiceId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[Integer]
    def nextToken: Optional[String]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getServiceIds: ZIO[Any, AwsError, List[VpcEndpointServiceId]] =
      AwsError.unwrapOptionField("serviceIds", serviceIds)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ) extends zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val serviceIds: Optional[List[VpcEndpointServiceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serviceIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.VpcEndpointServiceId(item)
          }.toList
        )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => value: Integer)
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest
  ): zio.aws.ec2.model.DescribeVpcEndpointServiceConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}
